;
; SM8X8
; Presets (EEPROM/Flash Content)
;
; ==========================================================================
;
; Copyright (C) 1998-2004  Thorsten Klose (Thorsten.Klose@midibox.org)
;                          http://www.uCApps.de
; 
; ==========================================================================
; 
; This file is part of SM8X8
;
; SM8X8 is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; SM8X8 is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with SM8X8; if not, write to the Free Software
; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
; ==========================================================================



; ==========================================================================
;  Data structure:
;                      Bank Offset       Internal Addr.   
;   +---------------+  0x4ff
;   | Reserved      |
;   +---------------+  0x400             -
;   | Configuration |
;   +---------------+  0x300             0x00 (EEPROM)
;   | Outgoing Evt  |
;   +---------------+  0x000             0x7800 (FLASH)
;

; ==========================================================================

	org	0x07800		; MIDI OUT events stored at the end of internal flash

;; This macro generates a MIDI OUT entry
;; Parameters: event_on_0, event_on_1, event_on_2, 
;;             event_off_0, event_off_1, event_off_2
;; normally we need 8 bits for every event byte, but since we are only able to 
;; embed 7-bit events within a SysEx stream, the MSB is masked out. 
;; However, the MSB (bit 8) is 1 for every MIDI event_xx_0 (0x80-0xff), therefore 
;; this doesn't hurt. Similar approach for event_xx_1 and event_xx_2: the MSB is 0 
;; for every MIDI event (0x00-0x7f), so we can get rid of it.

MIDIO_OUT_ENTRY MACRO event_on_0, event_on_1, event_on_2, event_off_0, event_off_1, event_off_2
	db	(event_on_0)&0x7f, (event_on_1)&0x7f, (event_on_2)&0x7f, (event_off_0)&0x7f, (event_off_1)&0x7f, (event_off_2)&0x7f
	ENDM

;; ---[ Incoming MIDI events which are assigned to the LEDs ]----------------
MIDIO_Presets
MIDIO_Presets_FLASH_Lower

;; ---[ Outgoing MIDI events which are triggered by input points at 
;;      intersections of the DOUT columns and DIN rows: Pin Col-Row ]-------- 

MIDIO_Presets_OffsetOut

	MIDIO_OUT_ENTRY	0x90, 0x18, 0x7f,   0x90, 0x18, 0x00		; Pin 0-0
	MIDIO_OUT_ENTRY	0x90, 0x19, 0x7f,   0x90, 0x19, 0x00		; Pin 0-1
	MIDIO_OUT_ENTRY	0x90, 0x20, 0x7f,   0x90, 0x20, 0x00		; Pin 0-2
	MIDIO_OUT_ENTRY	0x90, 0x21, 0x7f,   0x90, 0x21, 0x00		; Pin 0-3
	MIDIO_OUT_ENTRY	0x90, 0x22, 0x7f,   0x90, 0x22, 0x00		; Pin 0-4
	MIDIO_OUT_ENTRY	0x90, 0x23, 0x7f,   0x90, 0x23, 0x00		; Pin 0-5
	MIDIO_OUT_ENTRY	0x90, 0x24, 0x7f,   0x90, 0x24, 0x00		; Pin 0-6
	MIDIO_OUT_ENTRY	0x90, 0x25, 0x7f,   0x90, 0x25, 0x00		; Pin 0-7

	MIDIO_OUT_ENTRY	0x90, 0x26, 0x7f,   0x90, 0x26, 0x00		; Pin 1-0
	MIDIO_OUT_ENTRY	0x90, 0x27, 0x7f,   0x90, 0x27, 0x00		; Pin 1-1
	MIDIO_OUT_ENTRY	0x90, 0x28, 0x7f,   0x90, 0x28, 0x00		; Pin 1-2
	MIDIO_OUT_ENTRY	0x90, 0x29, 0x7f,   0x90, 0x29, 0x00		; Pin 1-3
	MIDIO_OUT_ENTRY	0x90, 0x2a, 0x7f,   0x90, 0x2a, 0x00		; Pin 1-4
	MIDIO_OUT_ENTRY	0x90, 0x2b, 0x7f,   0x90, 0x2b, 0x00		; Pin 1-5
	MIDIO_OUT_ENTRY	0x90, 0x2c, 0x7f,   0x90, 0x2c, 0x00		; Pin 1-6
	MIDIO_OUT_ENTRY	0x90, 0x2d, 0x7f,   0x90, 0x2d, 0x00		; Pin 1-7

	MIDIO_OUT_ENTRY	0x90, 0x2e, 0x7f,   0x90, 0x2e, 0x00		; Pin 2-0
	MIDIO_OUT_ENTRY	0x90, 0x2f, 0x7f,   0x90, 0x2f, 0x00		; Pin 2-1
	MIDIO_OUT_ENTRY	0x90, 0x30, 0x7f,   0x90, 0x30, 0x00		; Pin 2-2
	MIDIO_OUT_ENTRY	0x90, 0x31, 0x7f,   0x90, 0x31, 0x00		; Pin 2-3
	MIDIO_OUT_ENTRY	0x90, 0x32, 0x7f,   0x90, 0x32, 0x00		; Pin 2-4
	MIDIO_OUT_ENTRY	0x90, 0x33, 0x7f,   0x90, 0x33, 0x00		; Pin 2-5
	MIDIO_OUT_ENTRY	0x90, 0x34, 0x7f,   0x90, 0x34, 0x00		; Pin 2-6
	MIDIO_OUT_ENTRY	0x90, 0x35, 0x7f,   0x90, 0x35, 0x00		; Pin 2-7

	MIDIO_OUT_ENTRY	0x90, 0x36, 0x7f,   0x90, 0x36, 0x00		; Pin 3-0
	MIDIO_OUT_ENTRY	0x90, 0x37, 0x7f,   0x90, 0x37, 0x00		; Pin 3-1
	MIDIO_OUT_ENTRY	0x90, 0x38, 0x7f,   0x90, 0x38, 0x00		; Pin 3-2
	MIDIO_OUT_ENTRY	0x90, 0x39, 0x7f,   0x90, 0x39, 0x00		; Pin 3-3
	MIDIO_OUT_ENTRY	0x90, 0x3a, 0x7f,   0x90, 0x3a, 0x00		; Pin 3-4
	MIDIO_OUT_ENTRY	0x90, 0x3b, 0x7f,   0x90, 0x3b, 0x00		; Pin 3-5
	MIDIO_OUT_ENTRY	0x90, 0x3c, 0x7f,   0x90, 0x3c, 0x00		; Pin 3-6
	MIDIO_OUT_ENTRY	0x90, 0x3d, 0x7f,   0x90, 0x3d, 0x00		; Pin 3-7

	MIDIO_OUT_ENTRY	0x90, 0x3e, 0x7f,   0x90, 0x3e, 0x00		; Pin 4-0
	MIDIO_OUT_ENTRY	0x90, 0x3f, 0x7f,   0x90, 0x3f, 0x00		; Pin 4-1
	MIDIO_OUT_ENTRY	0x90, 0x40, 0x7f,   0x90, 0x40, 0x00		; Pin 4-2
	MIDIO_OUT_ENTRY	0x90, 0x41, 0x7f,   0x90, 0x41, 0x00		; Pin 4-3
	MIDIO_OUT_ENTRY	0x90, 0x42, 0x7f,   0x90, 0x42, 0x00		; Pin 4-4
	MIDIO_OUT_ENTRY	0x90, 0x43, 0x7f,   0x90, 0x43, 0x00		; Pin 4-5
	MIDIO_OUT_ENTRY	0x90, 0x44, 0x7f,   0x90, 0x44, 0x00		; Pin 4-6
	MIDIO_OUT_ENTRY	0x90, 0x45, 0x7f,   0x90, 0x45, 0x00		; Pin 4-7

	MIDIO_OUT_ENTRY	0x90, 0x46, 0x7f,   0x90, 0x46, 0x00		; Pin 5-0
	MIDIO_OUT_ENTRY	0x90, 0x47, 0x7f,   0x90, 0x47, 0x00		; Pin 5-1
	MIDIO_OUT_ENTRY	0x90, 0x48, 0x7f,   0x90, 0x48, 0x00		; Pin 5-2
	MIDIO_OUT_ENTRY	0x90, 0x49, 0x7f,   0x90, 0x49, 0x00		; Pin 5-3
	MIDIO_OUT_ENTRY	0x90, 0x4a, 0x7f,   0x90, 0x4a, 0x00		; Pin 5-4
	MIDIO_OUT_ENTRY	0x90, 0x4b, 0x7f,   0x90, 0x4b, 0x00		; Pin 5-5
	MIDIO_OUT_ENTRY	0x90, 0x4c, 0x7f,   0x90, 0x4c, 0x00		; Pin 5-6
	MIDIO_OUT_ENTRY	0x90, 0x4d, 0x7f,   0x90, 0x4d, 0x00		; Pin 5-7

	MIDIO_OUT_ENTRY	0x90, 0x4e, 0x7f,   0x90, 0x4e, 0x00		; Pin 6-0
	MIDIO_OUT_ENTRY	0x90, 0x4f, 0x7f,   0x90, 0x4f, 0x00		; Pin 6-1
	MIDIO_OUT_ENTRY	0x90, 0x50, 0x7f,   0x90, 0x50, 0x00		; Pin 6-2
	MIDIO_OUT_ENTRY	0x90, 0x51, 0x7f,   0x90, 0x51, 0x00		; Pin 6-3
	MIDIO_OUT_ENTRY	0x90, 0x52, 0x7f,   0x90, 0x52, 0x00		; Pin 6-4
	MIDIO_OUT_ENTRY	0x90, 0x53, 0x7f,   0x90, 0x53, 0x00		; Pin 6-5
	MIDIO_OUT_ENTRY	0x90, 0x54, 0x7f,   0x90, 0x54, 0x00		; Pin 6-6
	MIDIO_OUT_ENTRY	0x90, 0x55, 0x7f,   0x90, 0x55, 0x00		; Pin 6-7

	MIDIO_OUT_ENTRY	0x90, 0x56, 0x7f,   0x90, 0x56, 0x00		; Pin 7-0
	MIDIO_OUT_ENTRY	0x90, 0x57, 0x7f,   0x90, 0x57, 0x00		; Pin 7-1
	MIDIO_OUT_ENTRY	0x90, 0x58, 0x7f,   0x90, 0x58, 0x00		; Pin 7-2
	MIDIO_OUT_ENTRY	0x90, 0x59, 0x7f,   0x90, 0x59, 0x00		; Pin 7-3
	MIDIO_OUT_ENTRY	0x90, 0x5a, 0x7f,   0x90, 0x5a, 0x00		; Pin 7-4
	MIDIO_OUT_ENTRY	0x90, 0x5b, 0x7f,   0x90, 0x5b, 0x00		; Pin 7-5
	MIDIO_OUT_ENTRY	0x90, 0x5c, 0x7f,   0x90, 0x5c, 0x00		; Pin 7-6
	MIDIO_OUT_ENTRY	0x90, 0x5d, 0x7f,   0x90, 0x5d, 0x00		; Pin 7-7


	;; NOTE: in internal bank, all reads and writes from offset 0x200
	;; with be forwarded to the EEPROM address 0xf00000!
	;; by MIDIO_BANK_Write, MIDIO_BANK_Read

	org	0xf00000	; eeprom base address

MIDIO_Presets_OffsetGlobal

MIDIO_Presets_CFG0
	db	0x00, 0x00	; disable merger by default
MIDIO_Presets_DEBOUNCE_CTR
	db	(DEFAULT_SRIO_DEBOUNCE_CTR) & 0x0f, ((DEFAULT_SRIO_DEBOUNCE_CTR) >> 4)&0x0f
MIDIO_Presets_ALT_PROGCHNG
	db	DEFAULT_ALT_PROGCHNG&0x0f, 0x00
MIDIO_Presets_FORWARD_IO
	db	DEFAULT_FORWARD_IO&0x0f, 0x00
MIDIO_Presets_INVERSE_DIN
	db	DEFAULT_INVERSE_DIN&0x0f, 0x00
MIDIO_Presets_INVERSE_DOUT
	db	DEFAULT_INVERSE_DOUT&0x0f, 0x00	
MIDIO_Presets_TS_SENSITIVITY
	db	(DEFAULT_TS_SENSITIVITY)&0x0f, ((DEFAULT_TS_SENSITIVITY) >> 4)&0x0f
MIDIO_Presets_GLOBAL_CHANNEL
	db	0x00, 0x00
MIDIO_Presets_Reserved0
	db	0x00, 0x00
MIDIO_Presets_Reserved1
	db	0x00, 0x00
MIDIO_Presets_Reserved2
	db	0x00, 0x00
MIDIO_Presets_Reserved3
	db	0x00, 0x00
MIDIO_Presets_Reserved4
	db	0x00, 0x00
MIDIO_Presets_Reserved5
	db	0x00, 0x00
MIDIO_Presets_Reserved6
	db	0x00, 0x00
MIDIO_Presets_Reserved7
	db	0x00, 0x00

MIDIO_Presets_DIN_MODES		; 1 nibble for every input point

	db	0x00, 0x00	; PIN 0-3 to 0-0
	db	0x00, 0x00	; PIN 0-7 to 0-4

	db	0x00, 0x00	; PIN 1-3 to 1-0
	db	0x00, 0x00	; PIN 1-7 to 1-4

	db	0x00, 0x00	; PIN 2-3 to 2-0
	db	0x00, 0x00	; PIN 2-7 to 2-4

	db	0x00, 0x00	; PIN 3-3 to 3-0
	db	0x00, 0x00	; PIN 3-7 to 3-4

	db	0x00, 0x00	; PIN 4-3 to 4-0
	db	0x00, 0x00	; PIN 4-7 to 4-4

	db	0x00, 0x00	; PIN 5-3 to 5-0
	db	0x00, 0x00	; PIN 5-7 to 5-4

	db	0x00, 0x00	; PIN 6-3 to 6-0
	db	0x00, 0x00	; PIN 6-7 to 6-4

	db	0x00, 0x00	; PIN 7-3 to 7-0
	db	0x00, 0x00	; PIN 7-7 to 7-4

	;; fill unused area
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
	db	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0


	;; these two entries cannot be overwritten via SysEx.
	;; it contains the device ID and the to-COM option

EEPROM_READONLY
	db	0x00, DEFAULT_DEVICE_ID

